@@ -5,7 +5,7 @@
 
     Continuity command line interface.
 
-    :copyright: 2012 by Jonathan Zempel.
+    :copyright: 2013 by Jonathan Zempel.
     :license: BSD, see LICENSE for more details.
 """
 
@@ -517,14 +517,21 @@ def backlog(arguments):
     """
     git = _git()
     token = _get_value(git, "pivotal", "api-token")
+    parser = ArgumentParser()
+    parser.add_argument("-m", "--mywork", action="store_true",
+            help="list stories owned by you")
+    namespace = ContinuityNamespace(git)
+    parser.parse_args(arguments.all, namespace=namespace)
     pt = PivotalTracker(token)
+    owner = _get_value(git, "pivotal", "owner")
     project_id = _get_value(git, "pivotal", "project-id")
     project = pt.get_project(project_id)
     stories = pt.get_backlog(project.id)
     output = StringIO()
 
     for story in stories:
-        if story.state in [Story.STATE_UNSCHEDULED, Story.STATE_UNSTARTED]:
+        if story.state in [Story.STATE_UNSCHEDULED, Story.STATE_UNSTARTED] \
+                and (namespace.mywork is False or story.owner == owner):
             id = colored.yellow(str(story.id))
 
             if story.estimate is None:
@@ -710,6 +717,10 @@ def issue(arguments):
     if issue:
         puts(issue.title)
 
+        if issue.milestone:
+            puts()
+            puts("Milestone: {0}".format(issue.milestone))
+
         if issue.description:
             puts()
             puts(colored.cyan(issue.description))
@@ -730,10 +741,21 @@ def issues(arguments):
 
     :tracker github:
     """
-    git = Git()
+    git = _git()
     token = _get_value(git, "github", "oauth-token")
+    parser = ArgumentParser()
+    parser.add_argument("-u", "--assignedtoyou", action="store_true",
+            help="list issues assigned to you")
+    namespace = ContinuityNamespace(git)
+    parser.parse_args(arguments.all, namespace=namespace)
     github = GitHub(git, token)
-    issues = _get_issues(github)
+
+    if namespace.assignedtoyou:
+        user = github.get_user()
+        issues = _get_issues(github, assignee=user.login)
+    else:
+        issues = _get_issues(github)
+
     output = StringIO()
 
     for issue in issues:
@@ -746,11 +768,18 @@ def issues(arguments):
         else:
             title = issue.title
 
-        if issue.assignee:
-            login = issue.assignee.login
-            title = "{0} ({1})".format(title, login)
+        information = issue.assignee
 
-        message = "{0}: {1}\n".format(number, title)
+        if information:
+            if issue.milestone:
+                information = "{0}, {1}".format(information, issue.milestone)
+        else:
+            information = issue.milestone
+
+        if information:
+            title = "{0} ({1})".format(title, information)
+
+        message = "{0}: {1}\n".format(number, title.strip())
         output.write(message)
 
     pipepager(output.getvalue(), cmd="less -FRSX")
@@ -839,6 +868,12 @@ def start(arguments):
 
     namespace = ContinuityNamespace(git)
     parser.parse_args(arguments.all, namespace=namespace)
+    integration_branch = _get_value(git, "continuity", "integration-branch")
+
+    if git.branch.name != integration_branch:
+        message = "error: Attempted start from non-integration branch, switch to '{0}'."  # NOQA
+        puts_err(message.format(integration_branch))
+        exit(128)
 
     if tracker == "github":
         token = _get_value(git, "github", "oauth-token")
